@@ -3,12 +3,13 @@
 //
 //  This file is part of Linterna Mágica
 //
+// Copyright (C) 2010, 2011, 2012, 2013 Ivaylo Valkov <ivaylo@e-valkov.org>
 // Copyright (C) 2010, 2011, 2012 Ivaylo Valkov <ivaylo@e-valkov.org>
 // Copyright (C) 2010, 2011 Ivaylo Valkov <ivaylo@e-valkov.org>
 // Copyright (C) 2010 Anton Katsarov <anton@katsarov.org>
 // Copyright (C) 2011, 2012 Ivaylo Valkov <ivaylo@e-valkov.org>
 // Copyright (C) 2011 Ivaylo Valkov <ivaylo@e-valkov.org>
-// Copyright (C) 2012 Ivaylo Valkov <ivaylo@e-valkov.org>
+// Copyright (C) 2012 Ivaylo Valkov <ivaylo@e-valkov.org>LinternaMagica.prototype.copyrights.push("Copyright (C) 2010, 2011, 2012,"+
 //
 // 
 //  The JavaScript code in this page (or file) is free software: you
@@ -33,7 +34,7 @@
 // ==UserScript==
 // @name           Linterna Mágica l10n bg_BG
 // @namespace Linterna Mágica
-// @description  Bulgarian localisation for Linterna Mágica version 0.0.12.
+// @description  Bulgarian localisation for Linterna Mágica version 0.0.13.
 // @include        http://*
 // @include        https://*
 
@@ -41,7 +42,7 @@
 
 var LM_L10N={"bg_BG":{ "__PO_HEADER":{
 "Project-Id-Version":"linterna_magica svn-trunk", "Report-Msgid-Bugs-To":"",
-"POT-Creation-Date":"2012-06-10 23:04+0300", "PO-Revision-Date":"2012-05-27 18:28+0300",
+"POT-Creation-Date":"2013-01-06 13:54+0200", "PO-Revision-Date":"2012-09-09 19:12+0300",
 "Last-Translator":"Ivaylo Valkov <ivaylo@e-valkov.org>", "Language-Team":"Bulgarian <ivaylo@e-valkov.org>",
 "Language":"bg", "MIME-Version":"1.0",
 "Content-Type":"text/plain; charset=UTF-8", "Content-Transfer-Encoding":"8bit",},
@@ -52,16 +53,19 @@ var LM_L10N={"bg_BG":{ "__PO_HEADER":{
  "Apr" : "апр",
  "Aug" : "авг",
  "Buffering" : "Буфериране",
+ "Click to change the size" : "Натиснете, за да промените размера",
+ "Ctrl+double-click to select all messages" : "Натиснете два пъти с мишката докато държите клавиша Ctrl, за да изберете всички съобщения",
  "Date" : "Дата",
  "Debug messages" : "Отстраняване на грешки",
  "Dec" : "дек",
+ "Double-click to change the size" : "Натиснете да пъти, за да промените размера",
  "Download" : "Запазване",
  "Feb" : "фев",
  "Fullscreen" : "На цял екран",
  "GNU  General Public License (GNU GPL)" : "Общия публичен лиценз на GNU (GNU GPL)",
  "HQ" : "ВК",
  "HTML5" : "HTML5",
- "High quality" : "Високо качество",
+ "Hide debug messages" : "Скриване на съобщенията за отстраняване на грешки",
  "Higher quality" : "Високо качество",
  "Jan" : "яну",
  "Jul" : "юли",
@@ -73,7 +77,6 @@ var LM_L10N={"bg_BG":{ "__PO_HEADER":{
  "Linterna Mágica project page at Savannah" : "Страница на проекта Linterna Mágica в Savannah",
  "Loading" : "Зареждане",
  "Loading video..." : "Зареждане на клипа…",
- "Low quality" : "Ниско качество",
  "Mar" : "мар",
  "May" : "май",
  "Mute" : "Заглушаване",
@@ -90,13 +93,15 @@ var LM_L10N={"bg_BG":{ "__PO_HEADER":{
  "Read the news section at the home page" : "Прочетете новините на уеб страницата",
  "Remove log" : "Премахване на обекта",
  "Remove this button, if it overlaps images or text in the page." : "Премахнете този бутон, ако скрива изображения или текст от страницата.",
+ "Remove update notifier" : "Премахване на обекта",
  "Report a bug at our Savannah project page" : "Подайте доклад за грешка на страницата на проекта в Savannah",
  "Save the video clip" : "Запазване на видео клипа",
  "Sep" : "сеп",
- "Show/hide debug messages" : "Показване/скриване на съобщенията за отстраняване на грешки",
- "Stop" : "Спиране",
  "Switch between flash plugin and Linterna Mágica" : "Превключване между приставката за флаш и Linterna Mágica",
  "Switch between site's HTML5 player and Linterna Mágica" : "Превключване между възпрозивеждане чрез HTML5, предоставено от страницата и Linterna Mágica",
+ "Switch between the Gnash plugin for flash and Linterna Mágica" : "Превключване между приставката Gnash и Linterna Mágica",
+ "Switch between the Lightspark plugin for flash and Linterna Mágica" : "Превключване между приставката Lightspark и Linterna Mágica",
+ "Switch between the Totem Vegas plugin for flash and Linterna Mágica" : "Превключване между приставката Totem Vegas и Linterna Mágica",
  "This program is free software; " : "Тази програма е свободен софтуер. ",
  "Time" : "Време",
  "Translation" : "Превод",
