@@ -3,7 +3,7 @@
 //
 //  This file is part of Linterna Mágica
 //
-//  Copyright (C) 2010, 2011  Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2010, 2011, 2012, 2013 Ivaylo Valkov <ivaylo@e-valkov.org>
 //  Copyright (C) 2010  Anton Katsarov <anton@katsarov.org>
 //
 //  The JavaScript code in this page (or file) is free software: you
@@ -53,6 +53,8 @@ function LinternaMagica(params)
     // Could be a string, but we need integer.
     this.debug_level = parseInt(params.debug);
 
+    this.set_web_log_expand(params.web_log_expand);
+
     if (this.debug_level && params.log_to == "web")
     {
 	var logger = this.create_web_logger();
@@ -71,9 +73,6 @@ function LinternaMagica(params)
 	else
 	{
 	    body.appendChild(logger);
-	    // With fixed position this is not needed
-	    // var bottom =parseInt(body.clientHeight|| body.offsetHeight)-30;
-	    // logger.style.setProperty("top", bottom+"px", "important");
 	}
     }
     else
@@ -106,6 +105,10 @@ function LinternaMagica(params)
     // (with JSONP data) on every page. check_for_updates() is called
     // in create_video_object().
 
+    // Examine the option for updates and check if necessary.
+    this.updates_data = null;
+    this.check_for_updates();
+
     // Add the style sheet to the head of the document.
     this.create_stylesheet();
 
@@ -122,8 +125,11 @@ function LinternaMagica(params)
     {
 	// setInterval ids for the video time position counter function
 	this.player_timers = new Array();
-    }
 
+	// setTimout ids that hide the volume sliders
+	this.volume_slider_timers = new Array();
+    }
+ 
     var position_function = null ;
     if (this.plugin_is_installed)
     {
@@ -187,7 +193,7 @@ LinternaMagica.prototype.name =  "Linterna Mágica";
 
 // Release date string in POISIX time format (date +"%s")
 // FIXME: Add real string
-LinternaMagica.prototype.release_date = "1356179301";
+LinternaMagica.prototype.release_date = "1357458910";
 
 // The URL with information about the latest version. Must
 // return JSONP data:
@@ -197,7 +203,7 @@ LinternaMagica.prototype.release_date = "1356179301";
 //});
 LinternaMagica.prototype.updates_page =
     "http://linterna-magica.nongnu.org/downloads/updates.js";
-//    "http://localhost/linterna-magica/downloads/updates.js";
+//    "http://localhost/lm/downloads/updates.js";
 
 // When this is a function the internal _() function could be used.
 LinternaMagica.prototype.description = function()
@@ -223,6 +229,21 @@ LinternaMagica.prototype.license = function()
     );
 }
 
+// Two control bars (2x24)
+// One HD links buttom (1x24)
+// One logo button (1x116)
+// One close button after the logo (1x24) 
+LinternaMagica.prototype.absolute_min_height = 212;
+
+
+LinternaMagica.prototype.absolute_min_width = 300;
+LinternaMagica.prototype.min_width = 400;
+
+// One close button (1x24)
+// One logo button (1x146)
+// 1px border
+LinternaMagica.prototype.min_remote_object_height = 169;
+
 LinternaMagica.prototype.license_link =
     "https://www.gnu.org/licenses/gpl.html";
 
@@ -234,7 +255,7 @@ LinternaMagica.prototype.savannah_page =
     "https://savannah.nongnu.org/projects/linterna-magica";
 
 LinternaMagica.prototype.bug_report_link = 
-    "https://sv.nongnu.org/support/?func=additem&amp;group=linterna-magica";
+    "https://sv.nongnu.org/bugs/?func=additem&amp;group=linterna-magica";
 
 LinternaMagica.prototype.microblog_link =
     "https://identi.ca/group/linternamagica";
@@ -242,6 +263,10 @@ LinternaMagica.prototype.microblog_link =
 
 // This is filled during build from the Makefile
 LinternaMagica.prototype.copyrights = new Array();
+LinternaMagica.prototype.copyrights.push("Copyright (C) 2010, 2011, 2012,"+
+					 " 2013 Ivaylo Valkov <ivaylo@e-valkov.org>");
+LinternaMagica.prototype.copyrights.push("Copyright (C) 2010, 2011, 2012,"+
+					 " 2013 Anton Katsarov <anton@katsarov.org>");
 
 // This object holds all the functions to control
 // the playback via web controls
@@ -282,7 +307,6 @@ LinternaMagica.prototype.player.init = function(id)
 	    return null;
 	}
 
-	var text = knob.nextSibling;
 	var slider = knob.parentNode;
 	var vol = null;
 
@@ -326,8 +350,6 @@ LinternaMagica.prototype.player.init = function(id)
 
 	    knob.style.setProperty("left", pos+"px", "important");
 
-	    text.textContent = vol+"%";
-
 	    clearInterval(volume_interval);
 	}
     }
