@@ -3,7 +3,7 @@
 //
 //  This file is part of Linterna Mágica
 //
-//  Copyright (C) 2010, 2011  Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2010, 2011, 2012 Ivaylo Valkov <ivaylo@e-valkov.org>
 //  Copyright (C) 2010  Anton Katsarov <anton@katsarov.org>
 //
 //  The JavaScript code in this page (or file) is free software: you
@@ -32,7 +32,23 @@
 LinternaMagica.prototype.create_video_object = function(object_data)
 {
     if (typeof(object_data) !== "object")
+    {
 	return;
+    }
+
+    // Decrease the size for the object, so it all fits in the space
+    // allocated by the website
+    // height of all controls + borders
+    // 36 = 12 + 22 + 2
+    // 12 - time slider
+    // 22 - control barr
+    // 2 - borders 
+    // -1 = bottom border of the object
+    object_data.outer_height = object_data.height-1;
+    object_data.height -= this.controls ? 36 : 24;
+
+  
+    var toggle_plugin = null;
 
     var id = object_data.linterna_magica_id;
     this.log("LinternaMagica.create_video_object:\n"+
@@ -58,9 +74,7 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     }
 
     var container = document.createElement("div");
-    var header = document.createElement("div");
-    var script_name = document.createElement("a");
-    var dw_link = document.createElement("a");
+    var object_tag_wrapper = document.createElement("div");
     var object_tag = document.createElement("object");
     var message = document.createElement("p");
     var param = document.createElement("param");
@@ -68,6 +82,10 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     container.setAttribute("id", "linterna-magica-"+id);
     container.setAttribute("class", "linterna-magica");
 
+    if (object_data.width < this.min_width) {
+	container.setAttribute("class", "linterna-magica-lower");
+    }
+
     // Fix for rtl languages. See
     // https://savannah.nongnu.org/bugs/?32740
     // https://savannah.nongnu.org/task/?11056
@@ -86,25 +104,20 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     container.style.setProperty("width",
 				(object_data.width+"px"), "important");
 
-    header.setAttribute("class", "linterna-magica-header");
-    header.setAttribute("id", "linterna-magica-header-"+id);
-    header.style.setProperty("width",
-			     ((parseInt(object_data.width))+"px"),
-			     "important");
+    container.style.setProperty("height",
+				(object_data.outer_height+"px"), "important");
 
+    object_tag_wrapper.setAttribute("id", "linterna-magica-video-object-wrapper-"+id);
+    object_tag_wrapper.setAttribute("class", "linterna-magica-video-object-wrapper");
 
-    script_name.textContent = "Linterna Mágica";
-    script_name.setAttribute("href", "#");
-    script_name.setAttribute("title", this._("About")+ " Linterna Mágica");
-    script_name.setAttribute("id", "linterna-magica-logo-"+id);
-    script_name.setAttribute("class", "linterna-magica-logo");
+    object_tag_wrapper.style.setProperty("height", object_data.height+"px",
+				 "important");
 
-    var self = this;
-    script_name.addEventListener("click", function(ev)
-				 {
-				     var el = this;
-				     self.about.apply(self, [ev, el]);
-				 }, false);
+    object_tag_wrapper.style.setProperty("width", object_data.width+"px",
+				 "important");
+
+    object_tag_wrapper.style.setProperty("display", "block",
+					 "important");
 
     var site_html5_player =
 	this.find_site_html5_player_wrapper(object_data.parent);
@@ -112,130 +125,10 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     var toggle_plugin_switch_type = 
 	site_html5_player ? "html5" : "plugin";
 
-    // If the plugin is not installed this is useless
-    if (this.plugin_is_installed || site_html5_player)
-    {
-	// append before download link (first button in the header)
-	var toggle_plugin = 
-	    this.create_toggle_plugin_link(null,id,
-					   toggle_plugin_switch_type);
-
-	header.appendChild(toggle_plugin);
-    }
-
-    dw_link.textContent = this._("Download");
-    dw_link.setAttribute("title", this._("Save the video clip"));
-
-    dw_link.setAttribute("id", "linterna-magica-video-download-link-"+id);
-    dw_link.setAttribute("class", "linterna-magica-video-download-link");
-    dw_link.setAttribute("href", object_data.link);
-
-    if (!object_data.link)
-    {
-	dw_link.style.setProperty("display", "none", "important");
-    }
-
-    header.appendChild(dw_link);
-
-    // Create HD links
-    if (object_data.hd_links)
-    {
-	var preferred_link = 
-	    this.compute_preferred_hd_link(object_data.hd_links);
-
-	// No link is calculated. Set to lowest.
-	if (preferred_link == null || isNaN(preferred_link))
-	{
-	    preferred_link = 
-		object_data.hd_links[object_data.hd_links.length-1];
-	}
-
-	var hd_wrapper = document.createElement("div");
-	var hd_button = document.createElement("a");
-	hd_button.setAttribute("href","#");
-	hd_button.textContent = this._("HQ");
-	hd_button.setAttribute("title", this._("Higher quality"));
-	hd_button.setAttribute("class", "linterna-magica-switch-hd");
-
-	var hd_button_click_function =  function(ev)
-	{
-	    var el = this;
-	    self.show_or_hide_hd_links.apply(self, [ev, el]);
-	};
-
-	hd_button.addEventListener("click",
-				   hd_button_click_function, false);
-
-	hd_wrapper.appendChild(hd_button);
-
-	var hd_links = document.createElement("div");
-	hd_links.setAttribute("id", "linterna-magica-hd-links-list-"+id);
-	hd_links.setAttribute("class", "linterna-magica-hd-links-list");
-	hd_links.style.setProperty("display","none","important");
-
-	var ul = document.createElement("ul");
-
-	for(var link=0; link<object_data.hd_links.length; link++)
-	{
-	    var li = document.createElement("li");
-	    var button = document.createElement("a");
-	    button.setAttribute("href",object_data.hd_links[link].url);
-	    button.textContent = object_data.hd_links[link].label;
-
-	    var button_click_function = function(ev)
-	    {
-		var el = this;
-		self.switch_to_hd_link.apply(self, [ev, el]);
-	    };
-
-	    button.addEventListener("click",
-				    button_click_function , false);
-
-	    // Preferred link 
-	    if (link == preferred_link)
-	    {
-		// Set the link in the interface
-		this.select_hd_link_in_list(button,id);
-
-		// Set the link for the player and download link.
-		object_data.link = object_data.hd_links[link].url;
-		dw_link.setAttribute("href",
-				     object_data.hd_links[link].url);
-	    }
-
-	    li.appendChild(button);
-	    ul.appendChild(li);
-	}
-	hd_links.appendChild(ul);
-	hd_wrapper.appendChild(hd_links);
-	header.appendChild(hd_wrapper);
-    }
-
-    header.appendChild(script_name);
-
-    // Log to web
-    if (this.debug_level && this.log_to == "web")
-    {
-	var log_link  =  this.create_web_log_link(id);
-
-	var log_link_click_function = function(ev)
-	{
-	    var el = this;
-	    self.show_or_hide_web_log.apply(self, [ev, el]);
-	};
-
-	log_link.addEventListener("click",
-				  log_link_click_function, false);
-
-	header.appendChild(log_link);
-	// Hide the web log, so it is accessible only from the interface.
-	var log = document.getElementById("linterna-magica-web-log");
-	log.style.setProperty("display","none", "important");
-    }
-
     object_tag.setAttribute("width", object_data.width);
     object_tag.setAttribute("height", object_data.height);
     object_tag.setAttribute("id","linterna-magica-video-object-"+id);
+    object_tag.setAttribute("class","linterna-magica-video-object");
     object_tag.setAttribute("standby", this._("Loading video..."));
 
     if (object_data.link)
@@ -264,6 +157,12 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     }
 
     message.textContent = this._("Waiting for video plugin...");
+    message.style.setProperty("height", object_data.height+"px",
+				 "important");
+
+    message.style.setProperty("width", object_data.width+"px",
+				 "important");
+
 
     param.setAttribute("name", "autoplay");
     // Find if a clip is already playing.
@@ -298,17 +197,15 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     object_tag.appendChild(param);
 
     object_tag.appendChild(message);
-    container.appendChild(header);
-    container.appendChild(object_tag);
+
+    object_tag_wrapper.appendChild(object_tag);
+    container.appendChild(object_tag_wrapper);
 
     var about_box = this.create_about_box(id);
-    // Fix dailymotion (otherwise it is set to 100%
-    // and it goes out of the "box")
-    about_box.style.setProperty("height",
-				// Using the exact height with small
-				// objects hides the homepage link.
-				(parseInt(object_data.height)-20)+"px",
+    // 40 = padding
+    about_box.style.setProperty("height", (object_data.height-40)+"px",
 				"important");
+
     container.appendChild(about_box);
     
     // Mark the object, so it is not processed and chacked after
@@ -322,7 +219,7 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     // Add link after the object/embed
     // this.set_priority() has set this.priority
     // to self if there is no plugin
-	if (this.plugin_is_installed || site_html5_player)
+    if (this.plugin_is_installed || site_html5_player)
     {
 	toggle_plugin =
 	    this.create_toggle_plugin_link("link-not-in-header", id,
@@ -332,16 +229,17 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 
 	if (this.plugin_is_installed && !site_html5_player)
 	{
-	    before = this.get_flash_video_object(id).nextSibling;
+	    before = this.get_flash_video_object(id) ?
+		this.get_flash_video_object(id) : null;
 	}
 	else if (site_html5_player)
 	{
-	    before = site_html5_player.nextSibling;
+	    before = site_html5_player;
 	}
 
-	if (before)
+	if (before && before.nextSibling)
 	{
-	    object_data.parent.insertBefore(toggle_plugin, before);
+	    object_data.parent.insertBefore(toggle_plugin, before.nextSibling);
 	}
 	else
 	{
@@ -358,19 +256,27 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	    toggle_plugin.style.setProperty("display", "none",
 					    "important");
 	}
+
+	this.add_css_class(object_data.parent, "linterna-magica-ws-video-parent");
     }
 
-    if (this.controls)
+    if (this.updates_data)
     {
-	var controls = this.create_controls(object_data);
-	container.appendChild(controls);
+	var update_info = this.create_update_info_box(id, object_data.height);
+	container.appendChild(update_info);
     }
 
-    var dom_object =  this.get_flash_video_object(id);
+    var controls = this.create_controls(object_data);
+    // Set the link if an HD preferred link was computed in the
+    // controls code.
+    object_tag.setAttribute("data", object_data.link);
+    container.appendChild(controls);
 
-    if (!dom_object)
+    var site_player =  this.get_flash_video_object(id);
+
+    if (!site_player)
     {
-	dom_object = site_html5_player;
+	site_player = site_html5_player;
     }
 
     // Remove/hide the object if it is in DOM
@@ -378,21 +284,22 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	  !site_html5_player) || 
 	 ((this.priority.self > this.priority.html5) &&
 	  site_html5_player)) &&
-	dom_object &&
+	site_player &&
 	// The object is still in DOM some scripts remove it
-	dom_object.parentNode)
+	site_player.parentNode)
     {
-	if(dom_object.nextSibling)
+	if(site_player.nextSibling)
 	{
-	    object_data.use_sibling = dom_object.nextSibling;
+	    object_data.use_sibling = site_player.nextSibling;
 	}
 
 	if (!site_html5_player)
 	{
-	    this.hide_flash_video_object(id,dom_object.parentNode);
+	    this.hide_flash_video_object(id,site_player.parentNode);
 	}
 	else 
 	{
+	    this.pause_site_html5_player(object_data.parent);
 	    this.hide_site_html5_player(object_data.parent);
 	}
     }
@@ -423,40 +330,27 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	((this.priority.self < this.priority.html5) && 
 	 site_html5_player))
     {
-	this.hide_lm_video(object_data.linterna_magica_id);
+	this.hide_lm_interface(object_data.linterna_magica_id);
     }
 
-    // Defaults style fixes applied always.
-    about_box.style.setProperty("overflow", "auto", "important");
-
-    container.style.setProperty("height",
-				((parseInt(object_data.height)+26+
-				  (this.controls ? 24 : 0))+"px"),
-				"important");
-
-    if (object_data.parent)
-    {
-	object_data.parent.style.setProperty("height",
-					     (parseInt(object_data.height)+
-					      26+
-					      // borders 1px x 2
-					      2+
-					      (this.controls ? 24 : 0))+"px",
-					     "important");
-    }
-
-    
-
-    var dom_object = this.get_flash_video_object(id);
     // Objects extracted from script usually does not have cloned object
     // For example youtube
-    if (dom_object)
+    if (site_player)
     {
 	// Prevent the object to fill the container at 100% (if set)
 	// This way the toggle plugin link after the object is not
 	// overlaping elements.
-	dom_object.style.setProperty("height", object_data.height+"px",
-				     "important");
+	site_player.style.setProperty("height", object_data.outer_height+"px",
+				      "important");
+
+
+	// Render site player above Linterna Mágica's button
+	site_player.style.setProperty("position", "relative", "important");
+	site_player.style.setProperty("z-index", "9999999", "important");
+	site_player.style.setProperty("background-color",
+				      "black", "important");
+	site_player.style.setProperty("border",
+				     "1px solid #36393E", "important");
     }
 
     // Prevent the video object to fill the area at 100% and overlap
@@ -485,37 +379,6 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	}
     }
 
-    // Fixes script crash in vimeo.com with firefox. if
-    // parent.parentNode is not an object
-    if (object_data.parent && object_data.parent.parentNode)
-    {
-	// dailymotion.com && metacafe.com && btn.bg
-	// These have single div inside another one
-	// which (through height) overlaps elemenst
-	// It is not good to be applied on parent.parentNode
-	// which has different number of childNodes
-	if ((object_data.parent.parentNode.childNodes.length === 3 &&
-	     // text node
-	     object_data.parent.parentNode.firstChild.nodeType === 3 &&
-	     object_data.parent.parentNode.lastChild.nodeType === 3) ||
-	    object_data.parent.parentNode.localName.toLowerCase() === "li")
-
-	{
-	    object_data.parent.parentNode.style.
-		setProperty("height",
-			    (parseInt(object_data.height)+26+
-			     // borders 1px x 2
-			     2+
-			     (this.controls ? 24 : 0)  )+"px",
-			    "important");
-
-	    this.log("LinternaMagica.create_video_object:\n"+
-		     "Detected single wrapper "+
-		     "element inside another one. Aplying parent.parent "+
-		     "height: "+(parseInt(object_data.height)+26)+"px", 4);
-	}
-    }
-
     // Init the web controls functions
     // only if Linterna Mágica has priority
     if (this.controls &&
@@ -524,8 +387,17 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	this.player.init.apply(this,[id]);
     }
 
-    // Examine the option for updates and check if necessary.
-    this.check_for_updates();
+    // The player name is needed for the this.player.stop function,
+    // which is called when LM is hidden. It is used in the toggle
+    // plugin button's function to stop the audio when LM is not
+    // visible to work-around dual playback. If the video plugin
+    // controls are used the this.player.init function is not called
+    // and the player name is not set. We need to set it manually. 
+    if (!this.controls && !this.get_player_name(id))
+    {
+	this.player.set_player_name.apply(this,[id]);
+    }
+
 
     // Various CSS fixes
     var self = this;
