@@ -3,7 +3,7 @@
 //
 //  This file is part of Linterna Mágica
 //
-//  Copyright (C) 2010, 2011  Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2010, 2011, 2012  Ivaylo Valkov <ivaylo@e-valkov.org>
 //  Copyright (C) 2010  Anton Katsarov <anton@katsarov.org>
 //
 //  The JavaScript code in this page (or file) is free software: you
@@ -106,6 +106,7 @@ LinternaMagica.prototype.create_youtube_links = function(fmt, fmt_url_map)
 		break;
 	    case '13':
 	    case '17':
+	    case '36':
 		label += " 3GP";
 		break;
 	    default:
@@ -156,6 +157,7 @@ LinternaMagica.prototype.create_youtube_links = function(fmt, fmt_url_map)
 		break;
 	    case '13':
 	    case '17':
+	    case '36':
 		more_info += "MPEG-4 Visual, AAC";
 		break;
 	    default:
@@ -212,7 +214,7 @@ LinternaMagica.prototype.detect_youtube_flash_upgrade = function(object_data)
     }
     
 
-    // With default timeout 2000mS this will be 10 sec. Stop checking and insert.    
+    // With default timeout 3000mS this will be >10 sec. Stop checking and insert.    
     // Might be flashblock
     if (document.getElementById("movie_player") ||
 	document.getElementById("movie_player-html5") ||
@@ -265,7 +267,7 @@ LinternaMagica.prototype.extract_youtube_fmt_url_map = function()
 	{
 	    // Usually the links have the following pattern
 	    // (itag=fmt_id)*url=URL&type=video/...&(itag=fmt_id)*
-	    var link = fmt[url].match(/url=([^&]+)/);
+	    var link = fmt[url].match(/(url|conn)=([^&]+)/);
 	    var fmt_id = fmt[url].match(/itag=([0-9]+)/);
 	    var sig = fmt[url].replace(/\\u0026/g, '&').match(/sig=[^&]+/);
 		sig = sig[sig.length-1].replace(/sig/,'signature');
@@ -274,6 +276,10 @@ LinternaMagica.prototype.extract_youtube_fmt_url_map = function()
 	    {
 		links++;
 		link = unescape(link[link.length-1]);
+		// Live streams support. 
+		// See bugs #36759:
+		// https://savannah.nongnu.org/bugs/?36759
+		link = link.replace(/\\u0026stream=/, '/');
 		link = link.split(/\\u0026/)[0];
 
 		map[fmt_id[fmt_id.length-1]] =  link+"&"+sig;
@@ -480,7 +486,7 @@ function(object_data)
 	this.youtube_flash_upgrade_timeout = setInterval(
 	    function() {
 		self.detect_youtube_flash_upgrade.apply(self,[data]);
-	    }, 2000);
+	    }, 3000);
     }
     
     return false;
@@ -581,30 +587,6 @@ function(object_data)
 	
     }
 
-    // Sometimes the toggle plugin button that should be bellow the
-    // HTML5/Flash player shows on top. The following tries to fix
-    // this.  Most of the time the bug occurs in Epiphany.s
-
-    var id = object_data.linterna_magica_id;
-    var toggle_plugin = document.getElementById("linterna-magica-toggle-plugin-"+id);
-    
-    if (toggle_plugin)
-    {
-	var lm = document.getElementById("linterna-magica-"+id);
-	var h_lm = parseInt(lm.style.getPropertyValue("height"));
-
-	toggle_plugin = toggle_plugin.parentNode;
-	var display = toggle_plugin.style.getPropertyValue("display");
-	var top = toggle_plugin.offsetTop;
-
-	if (!display && !top)
-	{
-	    toggle_plugin.style.setProperty("top", 
-					    (h_lm +30)+"px",
-					    "important");
-	}
-    }
-
     // When YouTube's HTML5 player detects that the browser does not
     // have support for any clip, a warning div is displayed. It must
     // be hidden or it displaces Linterna Magica.
@@ -646,24 +628,18 @@ function(object_data)
  	    {
 		// It should be available, because it is used above in
 		// this function
-		id = id ? id : object_data.linterna_magica_id;
+		var id = object_data.linterna_magica_id;
 
-		var lm = document.getElementById("linterna-magica-"+id);
-
-		if (!lm)
-		{
-		    return null;
-		}
-
-		lm.style.removeProperty("display");
+		this.show_lm_interface(id);
 	    
 		// It should be available, because it is used above in
 		// this functon.
-		toggle_plugin = toggle_plugin  ? toggle_plugin :
+		toggle_plugin = 
 		    document.getElementById("linterna-magica-"+
 					    "toggle-plugin-"+id);
 
-		toggle_plugin.parentNode.removeChild(toggle_plugin);
+		var pn = toggle_plugin.parentNode.parentNode;
+		pn.removeChild(toggle_plugin.parentNode);
 
 		toggle_plugin_header =
 		    document.getElementById("linterna-magica-"+
@@ -691,43 +667,24 @@ function(object_data)
 	}
     }
 
+    // Without this the toggle plugin stays hidden below the title of
+    // the clip
+    var watch7 = document.getElementById('watch7-player');
+    if (watch7)
+    {
+	watch7.style.setProperty("height", 
+				 (parseInt(object_data.outer_height)+
+				  24)+"px", "important");
+
+	var movie_player = document.getElementById("movie_player");
+	if (movie_player)
+	{
+	    movie_player.style.setProperty("height", 
+					   parseInt(object_data.outer_height)+
+					   "px", "important");
+	}
+    }
+
     return false;
 }
 
-// Fixes the overlapping of the HD links list in YouTube's new design
-// See bug #37881
-// http://savannah.nongnu.org/bugs/?37881
-LinternaMagica.prototype.sites["youtube.com"].post_show_hd_links_list =
-function()
-{
-    var play_list= document.getElementById("watch7-playlist-tray-container");
-    if (play_list)
-    {
-	play_list.style.setProperty("display", "none", "important");
-    }
-
-    var side_bar= document.getElementById("watch7-sidebar");
-    if (side_bar)
-    {
-	side_bar.style.setProperty("display", "none", "important");
-    }
-}
-
-// Fixes the overlapping of the HD links list in YouTube's new design
-// See bug #37881
-// http://savannah.nongnu.org/bugs/?37881
-LinternaMagica.prototype.sites["youtube.com"].post_hide_hd_links_list =
-function()
-{
-    var play_list= document.getElementById("watch7-playlist-tray-container");
-    if (play_list)
-    {
-	play_list.style.removeProperty("display");
-    }
-
-    var side_bar= document.getElementById("watch7-sidebar");
-    if (side_bar)
-    {
-	side_bar.style.removeProperty("display");
-    }
-}
